@@ -7,9 +7,9 @@ use threadpool::ThreadPool;
 use crate::config::{Config, Delimiter};
 use crate::index::Indexed;
 use crate::select::{SelectColumns, Selection};
-use crate::serde::Deserialize;
 use crate::util;
 use crate::CliResult;
+use serde::Deserialize;
 
 static USAGE: &str = "
 Compute a frequency table on CSV data.
@@ -45,6 +45,8 @@ frequency options:
                            an index already created. Note that a file handle
                            is opened for each job.
                            When set to '0', the number of jobs is set to the
+                           number of CPUs detected divided by 4.
+                           When set to '-1', the number of jobs is set to the
                            number of CPUs detected.
                            [default: 0]
 
@@ -66,7 +68,7 @@ struct Args {
     flag_limit: usize,
     flag_asc: bool,
     flag_no_nulls: bool,
-    flag_jobs: usize,
+    flag_jobs: isize,
     flag_output: Option<String>,
     flag_no_headers: bool,
     flag_delimiter: Option<Delimiter>,
@@ -198,10 +200,12 @@ impl Args {
     }
 
     fn njobs(&self) -> usize {
-        if self.flag_jobs == 0 {
-            util::num_cpus()
-        } else {
-            self.flag_jobs
+        let num_cpus = util::num_cpus();
+        match self.flag_jobs {
+          0 => util::max_jobs(),
+          flag_jobs if flag_jobs < 0 => num_cpus,
+          flag_jobs if flag_jobs > num_cpus as isize => num_cpus,
+          _ => self.flag_jobs as usize,
         }
     }
 }
