@@ -10,13 +10,16 @@ pub mod fill;
 pub mod fixlengths;
 pub mod flatten;
 pub mod fmt;
+#[cfg(feature = "foreach")]
 pub mod foreach;
 pub mod frequency;
+pub mod generate;
 pub mod headers;
 pub mod index;
 pub mod input;
 pub mod join;
 pub mod jsonl;
+#[cfg(feature = "lua")]
 pub mod lua;
 pub mod partition;
 pub mod pseudo;
@@ -24,7 +27,6 @@ pub mod rename;
 pub mod replace;
 pub mod reverse;
 pub mod sample;
-pub mod scramble;
 pub mod search;
 pub mod searchset;
 pub mod select;
