@@ -1,29 +1,4 @@
-extern crate byteorder;
-extern crate chrono;
 extern crate crossbeam_channel as channel;
-extern crate csv;
-extern crate csv_index;
-extern crate currency;
-extern crate dateparser;
-extern crate docopt;
-extern crate filetime;
-extern crate hlua;
-extern crate lazy_static;
-extern crate itertools;
-#[cfg(feature = "mimalloc")]
-extern crate mimalloc;
-extern crate num_cpus;
-extern crate rand;
-extern crate regex;
-extern crate reverse_geocoder;
-extern crate serde;
-extern crate serde_json;
-extern crate tabwriter;
-extern crate threadpool;
-extern crate indicatif;
-extern crate num_format;
-extern crate natural;
-extern crate uuid;
 
 use std::borrow::ToOwned;
 use std::env;
@@ -67,42 +42,43 @@ macro_rules! command_list {
     cat         Concatenate by row or column
     count       Count records
     dedup       Remove redundant rows
-    exclude     Excludes the records in one CSV from another
     enum        Add a new column enumerating CSV lines
+    exclude     Excludes the records in one CSV from another
     explode     Explode rows based on some column separator
     fill        Fill empty values
     fixlengths  Makes all records have same length
     flatten     Show one field per line
     fmt         Format CSV output (change field delimiter)
-    foreach     Loop over a CSV file to execute bash commands (*nix only)
+    foreach*    Loop over a CSV file to execute bash commands (*nix only)
     frequency   Show frequency tables
+    generate    Generate test data by profiling a CSV
     headers     Show header names
     help        Show this usage message.
     index       Create CSV index for faster access
     input       Read CSV data with special quoting rules
     join        Join CSV files
     jsonl       Convert newline-delimited JSON files to CSV
-    lua         Execute Lua script on CSV data
+    lua*        Execute Lua script on CSV data
     partition   Partition CSV data based on a column value
     pseudo      Pseudonymise the values of a column
     sample      Randomly sample CSV data
-    scramble    Randomly scramble a CSV
     rename      Rename the columns of CSV data efficiently
     replace     Replace patterns in CSV data
     reverse     Reverse rows of CSV data
     search      Search CSV data with a regex
     searchset   Search CSV data with a regex set
-    select      Select columns from CSV
+    select      Select, re-order, duplicate or drop columns
     slice       Slice records from CSV
-    sort        Sort CSV data
+    sort        Sort CSV data in alphabetical, numerical, reverse or random order
     split       Split CSV data into many files
-    stats       Compute basic statistics
+    stats       Infer data types and compute descriptive statistics
     table       Align CSV data into columns
     transpose   Transpose rows/columns of CSV data
+
+    * requires foreach/lua feature
 "
     };
 }
-
 mod cmd;
 mod config;
 mod index;
@@ -190,14 +166,17 @@ enum Command {
     FixLengths,
     Flatten,
     Fmt,
+    #[cfg(feature = "foreach")]
     ForEach,
     Frequency,
+    Generate,
     Headers,
     Help,
     Index,
     Input,
     Join,
     Jsonl,
+    #[cfg(feature = "lua")]
     Lua,
     Partition,
     Pseudo,
@@ -205,7 +184,6 @@ enum Command {
     Replace,
     Reverse,
     Sample,
-    Scramble,
     Search,
     SearchSet,
     Select,
@@ -243,6 +221,7 @@ impl Command {
             Command::Flatten => cmd::flatten::run(argv),
             Command::Fmt => cmd::fmt::run(argv),
             Command::Frequency => cmd::frequency::run(argv),
+            Command::Generate => cmd::generate::run(argv),
             Command::Headers => cmd::headers::run(argv),
             Command::Help => {
                 wout!("{}", USAGE);
@@ -252,6 +231,7 @@ impl Command {
             Command::Input => cmd::input::run(argv),
             Command::Join => cmd::join::run(argv),
             Command::Jsonl => cmd::jsonl::run(argv),
+            #[cfg(feature = "lua")]
             Command::Lua => cmd::lua::run(argv),
             Command::Partition => cmd::partition::run(argv),
             Command::Pseudo => cmd::pseudo::run(argv),
@@ -259,7 +239,6 @@ impl Command {
             Command::Replace => cmd::replace::run(argv),
             Command::Reverse => cmd::reverse::run(argv),
             Command::Sample => cmd::sample::run(argv),
-            Command::Scramble => cmd::scramble::run(argv),
             Command::Search => cmd::search::run(argv),
             Command::SearchSet => cmd::searchset::run(argv),
             Command::Select => cmd::select::run(argv),
@@ -269,6 +248,7 @@ impl Command {
             Command::Stats => cmd::stats::run(argv),
             Command::Table => cmd::table::run(argv),
             Command::Transpose => cmd::transpose::run(argv),
+            #[cfg(feature = "foreach")]
             Command::ForEach => cmd::foreach::run(argv),
         }
     }
