@@ -1,4 +1,6 @@
 use std::borrow::Cow;
+use std::cmp;
+use std::env;
 use std::fs;
 use std::io;
 use std::path::{Path, PathBuf};
@@ -10,15 +12,28 @@ use ::num_cpus;
 use docopt::Docopt;
 use serde::de::{Deserialize, DeserializeOwned, Deserializer, Error};
 
-use crate::indicatif::{ProgressBar, ProgressStyle};
-use crate::num_format::{SystemLocale, ToFormattedString};
 use crate::config::{Config, Delimiter};
 use crate::CliResult;
+use indicatif::{ProgressBar, ProgressStyle};
+use thousands::Separable;
 
 pub fn num_cpus() -> usize {
     num_cpus::get()
 }
 
+pub fn max_jobs() -> usize {
+    let cpus = num_cpus::get();
+    let max_jobs_env = match env::var("QSV_MAX_JOBS") {
+        Ok(val) => val.parse::<isize>().unwrap_or_default(),
+        Err(_) => 0,
+    };
+    match max_jobs_env {
+        x if x > cpus as isize => cpus,
+        x if x <= 0 => cmp::max(cpus / 4, 1),
+        _ => max_jobs_env as usize,
+    }
+}
+
 pub fn version() -> String {
     #[cfg(feature = "mimalloc")]
     let malloc_kind = "mimalloc".to_string();
@@ -33,7 +48,7 @@ pub fn version() -> String {
     match (maj, min, pat, pre) {
         (Some(maj), Some(min), Some(pat), Some(pre)) => {
             if pre.is_empty() {
-                return format!("{}.{}.{}-{}-{}", maj, min, pat, malloc_kind, num_cpus());
+                return format!("{}.{}.{}-{}-{}", maj, min, pat, malloc_kind, max_jobs());
             } else {
                 return format!(
                     "{}.{}.{}-{}-{}-{}",
@@ -42,7 +57,7 @@ pub fn version() -> String {
                     pat,
                     pre,
                     malloc_kind,
-                    num_cpus()
+                    max_jobs()
                 );
             }
         }
@@ -74,8 +89,9 @@ pub fn prep_progress(progress: &ProgressBar, record_count: u64) {
     );
     progress.set_message(format!(
         " of {} records",
-        record_count.to_formatted_string(&SystemLocale::default().unwrap())
+        record_count.separate_with_commas()
     ));
+    progress.set_draw_delta(record_count / 100);
 }
 
 pub fn finish_progress(progress: &ProgressBar) {
@@ -83,13 +99,13 @@ pub fn finish_progress(progress: &ProgressBar) {
 
     let finish_template = format!(
         "[{{elapsed_precise}}] [{{bar:20}} {{percent}}%{{msg}}] ({}/sec)",
-        per_sec_rate.to_formatted_string(&SystemLocale::default().unwrap())
+        per_sec_rate.separate_with_commas()
     );
 
     progress.set_style(
         ProgressStyle::default_bar()
             .template(&finish_template)
-            .progress_chars("=>-")
+            .progress_chars("=>-"),
     );
     progress.finish();
 }
